# Changelog for https://gitlab.com/mbarkhau/myenv

## v201812.0003-beta

 - Add config parsing
 - Simplify instantiation (no need to import myenv to use subclasses)
 - Switch to https://gitlab.com/mbarkhau/myenv
 - Use https://gitlab.com/mbarkhau/bootstrapit

## v201809.0001-beta

 - Initial release
